@@ -1,23 +1,34 @@
 import argparse
 import os
+import sys
 from typing import List, Optional, Text, Dict
+
+from rasa.cli import SubParsersAction
 import rasa.cli.arguments.train as train_arguments
 
-from rasa.cli.utils import get_validated_path, missing_config_keys, print_error
-from rasa.constants import (
-    DEFAULT_CONFIG_PATH,
-    DEFAULT_DATA_PATH,
-    DEFAULT_DOMAIN_PATH,
-    CONFIG_MANDATORY_KEYS_NLU,
+import rasa.cli.utils
+from rasa.shared.utils.cli import print_error
+from rasa.shared.constants import (
     CONFIG_MANDATORY_KEYS_CORE,
+    CONFIG_MANDATORY_KEYS_NLU,
     CONFIG_MANDATORY_KEYS,
+    DEFAULT_CONFIG_PATH,
+    DEFAULT_DOMAIN_PATH,
+    DEFAULT_DATA_PATH,
 )
 
+import rasa.utils.common
+
 
-# noinspection PyProtectedMember
 def add_subparser(
-    subparsers: argparse._SubParsersAction, parents: List[argparse.ArgumentParser]
-):
+    subparsers: SubParsersAction, parents: List[argparse.ArgumentParser]
+) -> None:
+    """Add all training parsers.
+
+    Args:
+        subparsers: subparser we are going to attach to
+        parents: Parent parsers, needed to ensure tree structure in argparse
+    """
     train_parser = subparsers.add_parser(
         "train",
         help="Trains a Rasa model using your NLU data and stories.",
@@ -54,14 +65,16 @@ def add_subparser(
 def train(args: argparse.Namespace) -> Optional[Text]:
     import rasa
 
-    domain = get_validated_path(
+    domain = rasa.cli.utils.get_validated_path(
         args.domain, "domain", DEFAULT_DOMAIN_PATH, none_is_valid=True
     )
 
     config = _get_valid_config(args.config, CONFIG_MANDATORY_KEYS)
 
     training_files = [
-        get_validated_path(f, "data", DEFAULT_DATA_PATH, none_is_valid=True)
+        rasa.cli.utils.get_validated_path(
+            f, "data", DEFAULT_DATA_PATH, none_is_valid=True
+        )
         for f in args.data
     ]
 
@@ -73,7 +86,8 @@ def train(args: argparse.Namespace) -> Optional[Text]:
         force_training=args.force,
         fixed_model_name=args.fixed_model_name,
         persist_nlu_training_data=args.persist_nlu_data,
-        additional_arguments=extract_additional_arguments(args),
+        core_additional_arguments=extract_core_additional_arguments(args),
+        nlu_additional_arguments=extract_nlu_additional_arguments(args),
     )
 
 
@@ -81,18 +95,16 @@ def train_core(
     args: argparse.Namespace, train_path: Optional[Text] = None
 ) -> Optional[Text]:
     from rasa.train import train_core
-    import asyncio
 
-    loop = asyncio.get_event_loop()
     output = train_path or args.out
 
-    args.domain = get_validated_path(
+    args.domain = rasa.cli.utils.get_validated_path(
         args.domain, "domain", DEFAULT_DOMAIN_PATH, none_is_valid=True
     )
-    story_file = get_validated_path(
+    story_file = rasa.cli.utils.get_validated_path(
         args.stories, "stories", DEFAULT_DATA_PATH, none_is_valid=True
     )
-    additional_arguments = extract_additional_arguments(args)
+    additional_arguments = extract_core_additional_arguments(args)
 
     # Policies might be a list for the compare training. Do normal training
     # if only list item was passed.
@@ -114,7 +126,7 @@ def train_core(
     else:
         from rasa.core.train import do_compare_training
 
-        loop.run_until_complete(
+        rasa.utils.common.run_in_loop(
             do_compare_training(args, story_file, additional_arguments)
         )
 
@@ -127,10 +139,15 @@ def train_nlu(
     output = train_path or args.out
 
     config = _get_valid_config(args.config, CONFIG_MANDATORY_KEYS_NLU)
-    nlu_data = get_validated_path(
+    nlu_data = rasa.cli.utils.get_validated_path(
         args.nlu, "nlu", DEFAULT_DATA_PATH, none_is_valid=True
     )
 
+    if args.domain:
+        args.domain = rasa.cli.utils.get_validated_path(
+            args.domain, "domain", DEFAULT_DOMAIN_PATH, none_is_valid=True
+        )
+
     return train_nlu(
         config=config,
         nlu_data=nlu_data,
@@ -138,10 +155,12 @@ def train_nlu(
         train_path=train_path,
         fixed_model_name=args.fixed_model_name,
         persist_nlu_training_data=args.persist_nlu_data,
+        additional_arguments=extract_nlu_additional_arguments(args),
+        domain=args.domain,
     )
 
 
-def extract_additional_arguments(args: argparse.Namespace) -> Dict:
+def extract_core_additional_arguments(args: argparse.Namespace) -> Dict:
     arguments = {}
 
     if "augmentation" in args:
@@ -152,12 +171,32 @@ def extract_additional_arguments(args: argparse.Namespace) -> Dict:
     return arguments
 
 
+def extract_nlu_additional_arguments(args: argparse.Namespace) -> Dict:
+    arguments = {}
+
+    if "num_threads" in args:
+        arguments["num_threads"] = args.num_threads
+
+    return arguments
+
+
 def _get_valid_config(
     config: Optional[Text],
     mandatory_keys: List[Text],
     default_config: Text = DEFAULT_CONFIG_PATH,
 ) -> Text:
-    config = get_validated_path(config, "config", default_config)
+    """Get a config from a config file and check if it is valid.
+
+    Exit if the config isn't valid.
+
+    Args:
+        config: Path to the config file.
+        mandatory_keys: The keys that have to be specified in the config file.
+        default_config: default config to use if the file at `config` doesn't exist.
+
+    Returns: The path to the config file if the config is valid.
+    """
+    config = rasa.cli.utils.get_validated_path(config, "config", default_config)
 
     if not os.path.exists(config):
         print_error(
@@ -165,15 +204,15 @@ def _get_valid_config(
             "valid config file."
             "".format(config)
         )
-        exit(1)
+        sys.exit(1)
 
-    missing_keys = missing_config_keys(config, mandatory_keys)
+    missing_keys = rasa.cli.utils.missing_config_keys(config, mandatory_keys)
     if missing_keys:
         print_error(
             "The config file '{}' is missing mandatory parameters: "
             "'{}'. Add missing parameters to config file and try again."
             "".format(config, "', '".join(missing_keys))
         )
-        exit(1)
+        sys.exit(1)
 
     return config  # pytype: disable=bad-return-type
