@@ -7,22 +7,24 @@ from functools import partial
 from typing import Any, List, Optional, Text, Union
 
 import rasa.core.utils
+import rasa.shared.utils.common
 import rasa.utils
 import rasa.utils.common
 import rasa.utils.io
-from rasa import model, server
+from rasa import model, server, telemetry
 from rasa.constants import ENV_SANIC_BACKLOG
 from rasa.core import agent, channels, constants
 from rasa.core.agent import Agent
 from rasa.core.brokers.broker import EventBroker
 from rasa.core.channels import console
 from rasa.core.channels.channel import InputChannel
-from rasa.core.interpreter import NaturalLanguageInterpreter
+import rasa.core.interpreter
 from rasa.core.lock_store import LockStore
 from rasa.core.tracker_store import TrackerStore
 from rasa.core.utils import AvailableEndpoints
-from rasa.utils.common import raise_warning
+import rasa.shared.utils.io
 from sanic import Sanic
+from asyncio import AbstractEventLoop
 
 logger = logging.getLogger()  # get the root logger
 
@@ -33,7 +35,7 @@ def create_http_input_channels(
     """Instantiate the chosen input channel."""
 
     if credentials_file:
-        all_credentials = rasa.utils.io.read_config_file(credentials_file)
+        all_credentials = rasa.shared.utils.io.read_config_file(credentials_file)
     else:
         all_credentials = {}
 
@@ -58,7 +60,9 @@ def _create_single_channel(channel, credentials) -> Any:
     else:
         # try to load channel based on class name
         try:
-            input_channel_class = rasa.utils.common.class_from_module_path(channel)
+            input_channel_class = rasa.shared.utils.common.class_from_module_path(
+                channel
+            )
             return input_channel_class.from_credentials(credentials)
         except (AttributeError, ImportError):
             raise Exception(
@@ -190,8 +194,7 @@ def serve_application(
     protocol = "https" if ssl_context else "http"
 
     logger.info(
-        "Starting Rasa server on "
-        "{}".format(constants.DEFAULT_SERVER_FORMAT.format(protocol, port))
+        f"Starting Rasa server on {constants.DEFAULT_SERVER_FORMAT.format(protocol, port)}"
     )
 
     app.register_listener(
@@ -204,18 +207,23 @@ def serve_application(
         if app.agent.model_directory:
             shutil.rmtree(_app.agent.model_directory)
 
+    number_of_workers = rasa.core.utils.number_of_sanic_workers(
+        endpoints.lock_store if endpoints else None
+    )
+
+    telemetry.track_server_start(
+        input_channels, endpoints, model_path, number_of_workers, enable_api
+    )
+
     app.register_listener(clear_model_files, "after_server_stop")
 
     rasa.utils.common.update_sanic_log_level(log_file)
-
     app.run(
         host="0.0.0.0",
         port=port,
         ssl=ssl_context,
         backlog=int(os.environ.get(ENV_SANIC_BACKLOG, "100")),
-        workers=rasa.core.utils.number_of_sanic_workers(
-            endpoints.lock_store if endpoints else None
-        ),
+        workers=number_of_workers,
     )
 
 
@@ -225,7 +233,7 @@ async def load_agent_on_start(
     endpoints: AvailableEndpoints,
     remote_storage: Optional[Text],
     app: Sanic,
-    loop: Text,
+    loop: AbstractEventLoop,
 ):
     """Load an agent.
 
@@ -236,7 +244,9 @@ async def load_agent_on_start(
     try:
         with model.get_model(model_path) as unpacked_model:
             _, nlu_model = model.get_model_subdirectories(unpacked_model)
-            _interpreter = NaturalLanguageInterpreter.create(endpoints.nlu or nlu_model)
+            _interpreter = rasa.core.interpreter.create_interpreter(
+                endpoints.nlu or nlu_model
+            )
     except Exception:
         logger.debug(f"Could not load interpreter from '{model_path}'.")
         _interpreter = None
@@ -247,19 +257,25 @@ async def load_agent_on_start(
 
     model_server = endpoints.model if endpoints and endpoints.model else None
 
-    app.agent = await agent.load_agent(
-        model_path,
-        model_server=model_server,
-        remote_storage=remote_storage,
-        interpreter=_interpreter,
-        generator=endpoints.nlg,
-        tracker_store=_tracker_store,
-        lock_store=_lock_store,
-        action_endpoint=endpoints.action,
-    )
+    try:
+        app.agent = await agent.load_agent(
+            model_path,
+            model_server=model_server,
+            remote_storage=remote_storage,
+            interpreter=_interpreter,
+            generator=endpoints.nlg,
+            tracker_store=_tracker_store,
+            lock_store=_lock_store,
+            action_endpoint=endpoints.action,
+        )
+    except Exception as e:
+        rasa.shared.utils.io.raise_warning(
+            f"The model at '{model_path}' could not be loaded. " f"Error: {e}"
+        )
+        app.agent = None
 
     if not app.agent:
-        raise_warning(
+        rasa.shared.utils.io.raise_warning(
             "Agent could not be loaded with the provided configuration. "
             "Load default agent without any model."
         )
@@ -272,12 +288,5 @@ async def load_agent_on_start(
             remote_storage=remote_storage,
         )
 
+    logger.info("Rasa server is up and running.")
     return app.agent
-
-
-if __name__ == "__main__":
-    raise RuntimeError(
-        "Calling `rasa.core.run` directly is no longer supported. "
-        "Please use `rasa run` to start a Rasa server or `rasa shell` to chat with "
-        "your bot on the command line."
-    )
