@@ -1,11 +1,16 @@
-from typing import Any, Dict, List, Text
+from typing import Any, Dict, List, Optional, Text
 
+from rasa.core.utils import get_dict_hash
+from rasa.nlu.constants import NUMBER_OF_SUB_TOKENS
+from rasa.nlu.model import Metadata
 from rasa.nlu.tokenizers.tokenizer import Token
 from rasa.nlu.tokenizers.whitespace_tokenizer import WhitespaceTokenizer
-from rasa.nlu.training_data import Message
+from rasa.shared.nlu.training_data.message import Message
+from rasa.utils import common
 import rasa.utils.train_utils as train_utils
 import tensorflow as tf
 
+
 TF_HUB_MODULE_URL = (
     "https://github.com/PolyAI-LDN/polyai-models/releases/download/v1.0/model.tar.gz"
 )
@@ -13,7 +18,6 @@ TF_HUB_MODULE_URL = (
 
 class ConveRTTokenizer(WhitespaceTokenizer):
     """Tokenizer using ConveRT model.
-
     Loads the ConveRT(https://github.com/PolyAI-LDN/polyai-models#convert)
     model from TFHub and computes sub-word tokens for dense
     featurizable attributes of each message object.
@@ -24,8 +28,8 @@ class ConveRTTokenizer(WhitespaceTokenizer):
         "intent_tokenization_flag": False,
         # Symbol on which intent should be split
         "intent_split_symbol": "_",
-        # Text will be tokenized with case sensitive as default
-        "case_sensitive": True,
+        # Regular expression to detect tokens
+        "token_pattern": None,
         # Remote URL of hosted model
         "model_url": TF_HUB_MODULE_URL,
     }
@@ -41,6 +45,16 @@ class ConveRTTokenizer(WhitespaceTokenizer):
 
         self.tokenize_signature = self.module.signatures["tokenize"]
 
+    @classmethod
+    def cache_key(
+        cls, component_meta: Dict[Text, Any], model_metadata: Metadata
+    ) -> Optional[Text]:
+        _config = common.update_existing_keys(cls.defaults, component_meta)
+        return f"{cls.name}-{get_dict_hash(_config)}"
+
+    def provide_context(self) -> Dict[Text, Any]:
+        return {"tf_hub_module": self.module}
+
     def _tokenize(self, sentence: Text) -> Any:
 
         return self.tokenize_signature(tf.convert_to_tensor([sentence]))[
@@ -49,12 +63,11 @@ class ConveRTTokenizer(WhitespaceTokenizer):
 
     def tokenize(self, message: Message, attribute: Text) -> List[Token]:
         """Tokenize the text using the ConveRT model.
-
         ConveRT adds a special char in front of (some) words and splits words into
         sub-words. To ensure the entity start and end values matches the token values,
         tokenize the text first using the whitespace tokenizer. If individual tokens
-        are split up into multiple tokens, we make sure that the start end end value
-        of the first and last respective tokens stay the same.
+        are split up into multiple tokens, add this information to the
+        respected tokens.
         """
 
         # perform whitespace tokenization
@@ -63,21 +76,20 @@ class ConveRTTokenizer(WhitespaceTokenizer):
         tokens_out = []
 
         for token in tokens_in:
-            token_start, token_end, token_text = token.start, token.end, token.text
-
             # use ConveRT model to tokenize the text
-            split_token_strings = self._tokenize(token_text)[0]
+            split_token_strings = self._tokenize(token.text)[0]
 
             # clean tokens (remove special chars and empty tokens)
             split_token_strings = self._clean_tokens(split_token_strings)
 
-            tokens_out += train_utils.align_tokens(
-                split_token_strings, token_end, token_start
-            )
+            token.set(NUMBER_OF_SUB_TOKENS, len(split_token_strings))
+
+            tokens_out.append(token)
 
         return tokens_out
 
-    def _clean_tokens(self, tokens: List[bytes]):
+    @staticmethod
+    def _clean_tokens(tokens: List[bytes]) -> List[Text]:
         """Encode tokens and remove special char added by ConveRT."""
 
         tokens = [string.decode("utf-8").replace("﹏", "") for string in tokens]
